
.. _algorithms/drawing:

Drawing
*******

Algorithms
----------

.. automodule:: jgrapht.algorithms.drawing
   :members:

Types
-----

The result of the 2D drawing algorithms are instances of the following class.

.. autoclass:: jgrapht.types.LayoutModel2D
   :members: